/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { OnDestroy, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { IconDefinition } from '@fortawesome/fontawesome-common-types';
import { Subscription } from 'rxjs';
import { SidenavItem } from '../../interfaces/sidenav.interface';
import * as i0 from "@angular/core";
/**
 * A wrapper component for the `MatNavList` to be used to render in a
 * `MatSidenav`. This provides all necessary logic and styles to highlight and
 * expand `SidenavItems` according to the current route. It also includes an
 * SCSS mixin for you to configure the colors to use for active sidenav items,
 * so you can ensure the sidenav theme matches the rest of your application.
 *
 * The component is automatically included in the `DefaultLayout`. If you use
 * the `DefaultLayout`, the only thing you need to do is define the array of
 * `SidenavItems` and include it as an input in the tag. You may use this
 * component without the `DefaultLayout` if you want to use it to create your
 * own layout.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <div fxLayout="column">
 *     <mat-sidenav-container class="content" fxLayout="row">
 *         <mat-sidenav [mode]="mode">
 *             <ngx-mat-sidenav [sidenavItems]="sidenavItems"></ngx-mat-sidenav>
 *         </mat-sidenav>
 *         <mat-sidenav-content fxFlex>
 *             <router-outlet></router-outlet>
 *         </mat-sidenav-content>
 *     </mat-sidenav-container>
 * </div>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {SidenavItem} from '@ngx-material-dashboard/widgets';
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * })
 * export class BasicUsageExample {
 *     mode = 'side';
 *     sidenavItems: SidenavItem[] = [
 *         { queryParams: { isComplete: false }, route: ['tasks'], text: 'Pending', selector: 'pending' },
 *         { queryParams: { isComplete: false, filter: 'overdue' }, route: ['tasks'], text: 'Over Due', selector: 'over-due' },
 *         { queryParams: { isComplete: true }, route: ['tasks'], text: 'Complete', selector: 'complete' }
 *     ];
 * }
 * ```
 *
 * @overviewDetails
 * #### Features
 *
 * The `Sidenav` has several features including the ability to render nested
 * `SidenavItems`, icons with each `SidenavItem`, and custom `tooltips` to
 * render when the user hovers over a `SidenavItem`.
 *
 * ##### Nested SidenavItems
 *
 * The `Sidenav` allows you to define basic or nested `SidenavItems`. A basic
 * `Sidenav` item should have a route defined, while a nested `SidenavItem`
 * should have children defined. Nested `SidenavItems` will expand to display
 * any children. Currently the `Sidenav` will only render 2 levels of
 * `children`, meaning you can only define a parent, child, and grandchildren
 * `SidenavItems`. The grandchildren `SidenavItems` should all define a `route`.
 *
 * ##### Icons
 *
 * You may define a fontawesome icon for each of the items rendered in the
 * `Sidenav`. The icons will be rendered to the left of the text you include
 * for the `SidenavItem`.
 *
 * ##### Tooltip
 *
 * You may define text to render as a `tooltip` for when the user hovers over
 * a `SidenavItem`. The text displayed with the `SidenavItem` itself should be
 * mostly self explanatory, but this allows you to include some additional
 * details to the user when they hover over a `SidenavItem`.
 *
 * See the [Sidenav](/widgets/layout/overview#sidenav) interface documentation for
 * more details on the values to include when defining your `SidenavItems`.
 */
export declare class SidenavComponent implements OnDestroy, OnInit {
    private route;
    private router;
    /** The array of items to display in the sidenav. */
    set sidenavItems(sidenavItems: SidenavItem[]);
    /** Angle down icon displayed for expanded sidenav items. */
    faAngleDown: IconDefinition;
    /** Angle right icon displayed for collapsed sidenav items. */
    faAngleRight: IconDefinition;
    /** Any query params  */
    queryParams: any;
    /** The array of items to display in the sidenav. */
    sidenavItems$: SidenavItem[];
    /** The subscriptions for the component. */
    sub: Subscription;
    /** Tracks the toggle status for items in sidenav. */
    toggle: {
        toggle: boolean;
        children: boolean[];
    }[];
    constructor(route: ActivatedRoute, router: Router);
    ngOnDestroy(): void;
    ngOnInit(): void;
    /**
     * Returns array of child SidenavItems if they exist for given item.
     *
     * @param item SidenavItem to get children from (if they exist).
     * @returns Children SidenavItems of given item (if they exist).
     */
    getChildrenByItem(item: SidenavItem): SidenavItem[] | undefined;
    /**
     * Initializes sidenav items and toggle state based on current URL.
     */
    private initSidenavItems;
    /**
     * Returns true if the current URL ends with the route in the given
     * SidenavItem. Used to determine when to add the selected-list-item
     * class to a mat-list-item in the sidenav.
     *
     * @param sidenavItem The sidenav item to test against the current URL.
     * @returns true if the current URL ends with the route in the given SidenavItem.
     */
    isActive(sidenavItem: SidenavItem, parent?: SidenavItem): boolean;
    /**
     * Returns true if the sidenav item associated with the given index in the
     * toggle property is toggled.
     *
     * @param i The index of the sidenav item in the toggle property.
     * @returns True if the sidenav item is toggled.
     */
    isToggled(i: number): boolean;
    /**
     * Returns true if the child sidenav item associated with the given parent
     * index and child index in the toggle property is toggled.
     *
     * @param i The index of the parent sidenav item.
     * @param iChild The index of the child sidenav item.
     * @returns True if the child sidenav item is toggled.
     */
    isChildToggled(i: number, iChild: number): boolean;
    /**
     * Navigates to the route of the given sidenavItem (if it exists).
     *
     * @param index The sidenav item selected.
     */
    select(index: number): void;
    /**
     * Navigates to the route of the given child sidenav item.
     *
     * @param index The index of the parent.
     * @param childIndex The index of the child.
     */
    selectChild(index: number, childIndex: number): void;
    /**
     * Navigates to the route of the given grandchild.
     *
     * @param index The index of the parent.
     * @param childIndex The index of the child.
     * @param grandChildIndex The index of the grandchild.
     */
    selectGrandChild(index: number, childIndex: number, grandChildIndex: number): void;
    /**
     * Compares the given maps and returns true if they are equal. The given
     * maps are equal if they have the same keys and associated values.
     *
     * @param obj1 A map to compare.
     * @param obj2 Another map to compare.
     * @returns True if the given maps are equal.
     */
    compareMaps(obj1: any, obj2: any): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<SidenavComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SidenavComponent, "ngx-mat-sidenav", never, { "sidenavItems": "sidenavItems"; }, {}, never, never>;
}
